MINOR: mux: Unlink ALPN and multiplexers to rather speak of mux protocols

Multiplexers are not necessarily associated to an ALPN. ALPN is a TLS extension,
so it is not always defined or used. Instead, we now rather speak of
multiplexer's protocols. So in this patch, there are no significative changes,
some structures and functions are just renamed.
diff --git a/src/connection.c b/src/connection.c
index 5d7f788..f750e3c 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -33,9 +33,9 @@
 struct pool_head *pool_head_connstream;
 struct xprt_ops *registered_xprt[XPRT_ENTRIES] = { NULL, };
 
-/* List head of all known muxes for ALPN */
-struct alpn_mux_list alpn_mux_list = {
-        .list = LIST_HEAD_INIT(alpn_mux_list.list)
+/* List head of all known muxes for PROTO */
+struct mux_proto_list mux_proto_list = {
+        .list = LIST_HEAD_INIT(mux_proto_list.list)
 };
 
 /* perform minimal intializations, report 0 in case of error, 1 if OK. */